TesterNestFlutter class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- debugLoggingEnabled → bool
-
no setter
- isEnabled → bool
-
no setter
- isInitialized → bool
-
no setter
Static Methods
-
connectFromText(
String input, {String? publicKeyOverride}) → Future< MyAppCrewConnectResult> -
connectTester(
String code) → Future< MyAppCrewConnectResult> -
connectWithClaimToken(
String claimToken) → Future< MyAppCrewConnectResult> -
disconnectTester(
) → Future< void> -
flushNow(
) → Future< void> -
getConnectedTester(
) → MyAppCrewTester? -
getDebugSnapshot(
) → DebugSnapshot -
init(
{String? publicKey, String? baseUrl, bool? enableLogs}) → Future< void> -
isTesterConnected(
) → bool -
logEvent(
String name, {Map< String, dynamic> ? params}) → void -
resetForTesting(
) → void -
setClientForTesting(
MyAppCrewClient client) → void -
setDebugLogging(
bool enabled) → void -
setOnTesterIdentityInvalid(
void handler(String reason)?) → void -
showConnectSheet(
BuildContext context, {bool showAsBottomSheet = true, String title = 'Connect tester', String subtitle = 'Enter the 6-digit Connect Code from your invite.', bool allowDismiss = true}) → Future< void>