MyAppCrew class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
connectFromText(String input, {String? publicKeyOverride})
→ Future<MyAppCrewConnectResult>
-
-
connectTester(String code)
→ Future<MyAppCrewConnectResult>
-
-
connectWithClaimToken(String claimToken)
→ Future<MyAppCrewConnectResult>
-
-
debugSnapshot()
→ Map<String, dynamic>
-
-
disconnectTester()
→ Future<void>
-
-
flushNow()
→ Future<void>
-
-
getConnectedTester()
→ MyAppCrewTester?
-
-
getDebugSnapshot()
→ DebugSnapshot
-
-
init({String? publicKey, String? baseUrl, bool? enableLogs})
→ Future<void>
-
-
initialize({required String publicKey, required String baseUrl, bool debugLogs = false})
→ Future<void>
-
-
isTesterConnected()
→ bool
-
-
logEvent(String name, {Map<String, dynamic>? params})
→ void
-
-
navigatorObserver()
→ NavigatorObserver?
-
-
setDebugLogging(bool enabled)
→ void
-
-
setOnTesterIdentityInvalid(void handler(String reason)?)
→ void
-
-
showConnectSheet(BuildContext context, {bool showAsBottomSheet = true, String title = 'Connect tester', String subtitle = 'Enter the 6-digit Connect Code from your invite.', bool allowDismiss = true})
→ Future<void>
-